@@ -1,18 +1,26 @@
 #!/usr/bin/env python
 
+"""
+Application main function and version.
+"""
+
 import sys
 
 from reportmix.config.builder import ConfigBuilder
 from reportmix.errors import AppError
 from reportmix.mixer import ReportMixer
 
+__version__ = "0.4.3"
+
 
 def main():
-    """Entry point for the application script"""
+    """
+    Entry point for the application script.
+    """
 
     # Load configuration
     try:
-        config = ConfigBuilder().build()
+        config = ConfigBuilder(__version__).build()
     except AppError:
         sys.exit(1)
 
